@@ -6,10 +6,12 @@
 #
 #    Author: Francis J. Lacoste <francis@iNsu.COM>
 #
-#    Copyright (c) 1999,2000 Francis J. Lacoste, iNsu Innovations Inc.
+#    Copyright (c) 1999,2000 iNsu Innovations Inc.
 #
 #    This program is free software; you can redistribute it and/or modify
-#    it under the terms same terms as perl itself.
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 2 of the License, or
+#    (at your option) any later version.
 #
 package Fwctl::Report;
 
@@ -55,7 +57,7 @@ etc.)
 =cut
 
 BEGIN {
-    ($VERSION) = '$Revision: 1.7 $' =~ /(Revision: ([\d.]+))/;
+    ($VERSION) = '$Revision: 1.8 $' =~ /(Revision: ([\d.]+))/;
     @ISA = qw( Exporter );
 
     @EXPORT = ();
@@ -1228,11 +1230,17 @@ __END__
 
 =head1 AUTHOR
 
-Copyright (c) 2000 Francis J. Lacoste and iNsu Innovations Inc.
+Francis J. Lacoste <francis.lacoste@iNsu.COM>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2000 iNsu Innovations Inc.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the terms as perl itself.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
 
 =head1 SEE ALSO
 
