@@ -3,12 +3,14 @@
 #
 #    This file is part of Fwctl.
 #
-#    Author: Francis J. Lacoste <francis@iNsu.COM>
+#    Author: Francis J. Lacoste <francis.lacoste@iNsu.COM>
 #
-#    Copyright (c) 1999,2000 Francis J. Lacoste, iNsu Innovations Inc.
+#    Copyright (c) 1999,2000 iNsu Innovations Inc.
 #
 #    This program is free software; you can redistribute it and/or modify
-#    it under the terms same terms as perl itself.
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 2 of the License, or
+#    (at your option) any later version.
 #
 package Fwtcl::Services::tftp;
 
@@ -32,6 +34,7 @@ sub new {
 }
 
 1;
+
 =pod
 
 =head1 NAME
@@ -46,6 +49,20 @@ Fwctl::Services::all - Fwctl module to handle tftp protocol.
 
 Service module to handle tftp protocol.
 
+=head1 AUTHOR
+
+Francis J. Lacoste <francis.lacoste@iNsu.COM>
+
+=head1 COPYRIGHT
+
+Copyright (c) 1999,2000 iNsu Innovations Inc.
+All rights reserved.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
 =head1 SEE ALSO
 
 fwctl(8) Fwctl(3) Fwctl::RuleSet(3)
